changeset 6d4da9dc90a1 in /z/repo/gem5
details: http://repo.gem5.org/gem5?cmd=changeset;node=6d4da9dc90a1
description:
        tests: Add a regression for the stack distance calculator

        Re-use the existing traffic generator regression, and enable the stack
        distance calculation in the comm monitor, along with the verification
        stack.

        The traffic generator config is also tuned to not increase the
        run-time too much (and actually have some address re-use).

diffstat:

 tests/configs/tgen-simple-mem.py                               |    6 +-
 tests/quick/se/70.tgen/ref/null/none/tgen-simple-mem/stats.txt |  312 +++++----
 tests/quick/se/70.tgen/tgen-simple-mem.cfg                     |   16 +-
 3 files changed, 195 insertions(+), 139 deletions(-)

diffs (truncated from 452 to 300 lines):

diff -r cd8aae15f89a -r 6d4da9dc90a1 tests/configs/tgen-simple-mem.py
--- a/tests/configs/tgen-simple-mem.py  Tue Dec 23 09:31:18 2014 -0500
+++ b/tests/configs/tgen-simple-mem.py  Tue Dec 23 09:31:18 2014 -0500
@@ -54,9 +54,11 @@
                                             voltage_domain =
                                             VoltageDomain()))
 
 # add a communication monitor, and also trace all the packets
 system.monitor = CommMonitor(trace_file = "monitor.ptrc.gz",
-                             trace_enable = True)
+                             trace_enable = True,
+                             stack_dist_calc = StackDistCalc(verify = True))
 
 # connect the traffic generator to the bus via a communication monitor
 system.cpu.port = system.monitor.slave
@@ -54,9 +54,11 @@
                                             VoltageDomain()))
 
-# add a communication monitor, and also trace all the packets
+# add a communication monitor, and also trace all the packets and
+# calculate and verify stack distance
 system.monitor = CommMonitor(trace_file = "monitor.ptrc.gz",
diff -r cd8aae15f89a -r 6d4da9dc90a1 
tests/quick/se/70.tgen/ref/null/none/tgen-simple-mem/stats.txt
--- a/tests/quick/se/70.tgen/ref/null/none/tgen-simple-mem/stats.txt    Tue Dec 
23 09:31:18 2014 -0500
+++ b/tests/quick/se/70.tgen/ref/null/none/tgen-simple-mem/stats.txt    Tue Dec 
23 09:31:18 2014 -0500
@@ -4,37 +4,88 @@
 sim_ticks                                100000000000                       # 
Number of ticks simulated
 final_tick                               100000000000                       # 
Number of ticks from beginning of simulation (restored from checkpoints and 
never reset)
 sim_freq                                 1000000000000                       # 
Frequency of simulated ticks
-host_tick_rate                            11160095249                       # 
Simulator tick rate (ticks/s)
-host_mem_usage                                 262112                       # 
Number of bytes of host memory used
-host_seconds                                     8.96                       # 
Real time elapsed on the host
+host_tick_rate                            31050955853                       # 
Simulator tick rate (ticks/s)
+host_mem_usage                                 209576                       # 
Number of bytes of host memory used
+host_seconds                                     3.22                       # 
Real time elapsed on the host
 system.clk_domain.voltage_domain.voltage            1                       # 
Voltage in Volts
 system.clk_domain.clock                          1000                       # 
Clock period in ticks
 system.physmem.bytes_read::cpu                     64                       # 
Number of bytes read from this memory
 system.physmem.bytes_read::total                   64                       # 
Number of bytes read from this memory
-system.physmem.bytes_written::cpu           213329152                       # 
Number of bytes written to this memory
-system.physmem.bytes_written::total         213329152                       # 
Number of bytes written to this memory
+system.physmem.bytes_written::cpu              853312                       # 
Number of bytes written to this memory
+system.physmem.bytes_written::total            853312                       # 
Number of bytes written to this memory
 system.physmem.num_reads::cpu                       1                       # 
Number of read requests responded to by this memory
 system.physmem.num_reads::total                     1                       # 
Number of read requests responded to by this memory
-system.physmem.num_writes::cpu                3333268                       # 
Number of write requests responded to by this memory
-system.physmem.num_writes::total              3333268                       # 
Number of write requests responded to by this memory
+system.physmem.num_writes::cpu                  13333                       # 
Number of write requests responded to by this memory
+system.physmem.num_writes::total                13333                       # 
Number of write requests responded to by this memory
 system.physmem.bw_read::cpu                       640                       # 
Total read bandwidth from this memory (bytes/s)
 system.physmem.bw_read::total                     640                       # 
Total read bandwidth from this memory (bytes/s)
-system.physmem.bw_write::cpu               2133291520                       # 
Write bandwidth from this memory (bytes/s)
-system.physmem.bw_write::total             2133291520                       # 
Write bandwidth from this memory (bytes/s)
-system.physmem.bw_total::cpu               2133292160                       # 
Total bandwidth to/from this memory (bytes/s)
-system.physmem.bw_total::total             2133292160                       # 
Total bandwidth to/from this memory (bytes/s)
+system.physmem.bw_write::cpu                  8533120                       # 
Write bandwidth from this memory (bytes/s)
+system.physmem.bw_write::total                8533120                       # 
Write bandwidth from this memory (bytes/s)
+system.physmem.bw_total::cpu                  8533760                       # 
Total bandwidth to/from this memory (bytes/s)
+system.physmem.bw_total::total                8533760                       # 
Total bandwidth to/from this memory (bytes/s)
+system.cpu.numPackets                           13334                       # 
Number of packets generated
+system.cpu.numRetries                               1                       # 
Number of retries
+system.cpu.retryTicks                            1672                       # 
Time spent waiting due to back-pressure (ticks)
 system.membus.trans_dist::ReadReq                   1                       # 
Transaction distribution
 system.membus.trans_dist::ReadResp                  1                       # 
Transaction distribution
-system.membus.trans_dist::WriteReq            3333268                       # 
Transaction distribution
-system.membus.trans_dist::WriteResp           3333267                       # 
Transaction distribution
-system.membus.pkt_count_system.monitor-master::system.physmem.port      
6666537                       # Packet count per connected master and slave 
(bytes)
-system.membus.pkt_count::total                6666537                       # 
Packet count per connected master and slave (bytes)
-system.membus.pkt_size_system.monitor-master::system.physmem.port    213329216 
                      # Cumulative packet size per connected master and slave 
(bytes)
-system.membus.pkt_size::total               213329216                       # 
Cumulative packet size per connected master and slave (bytes)
-system.membus.reqLayer0.occupancy         16666342328                       # 
Layer occupancy (ticks)
-system.membus.reqLayer0.utilization              16.7                       # 
Layer utilization (%)
-system.membus.respLayer0.occupancy         3333272000                       # 
Layer occupancy (ticks)
-system.membus.respLayer0.utilization              3.3                       # 
Layer utilization (%)
+system.membus.trans_dist::WriteReq              13333                       # 
Transaction distribution
+system.membus.trans_dist::WriteResp             13333                       # 
Transaction distribution
+system.membus.pkt_count_system.monitor-master::system.physmem.port        
26668                       # Packet count per connected master and slave 
(bytes)
+system.membus.pkt_count::total                  26668                       # 
Packet count per connected master and slave (bytes)
+system.membus.pkt_size_system.monitor-master::system.physmem.port       853376 
                      # Cumulative packet size per connected master and slave 
(bytes)
+system.membus.pkt_size::total                  853376                       # 
Cumulative packet size per connected master and slave (bytes)
+system.membus.reqLayer0.occupancy            66667328                       # 
Layer occupancy (ticks)
+system.membus.reqLayer0.utilization               0.1                       # 
Layer utilization (%)
+system.membus.respLayer0.occupancy           13338000                       # 
Layer occupancy (ticks)
+system.membus.respLayer0.utilization              0.0                       # 
Layer utilization (%)
+system.monitor.stack_dist_calc.readLinearHist::samples            0            
           # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::mean          nan               
        # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::gmean          nan              
         # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::stdev          nan              
         # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::0            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::1            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::2            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::3            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::4            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::5            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::6            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::7            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::8            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::9            0                  
     # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::10            0                 
      # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::11            0                 
      # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::12            0                 
      # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::13            0                 
      # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::14            0                 
      # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::15            0                 
      # Reads linear distribution
+system.monitor.stack_dist_calc.readLinearHist::total            0              
         # Reads linear distribution
+system.monitor.stack_dist_calc.readLogHist::samples            0               
        # Reads logarithmic distribution
+system.monitor.stack_dist_calc.writeLinearHist::samples         6676           
            # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::mean  3330.061863              
         # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::gmean  3328.226314             
          # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::stdev    68.678195             
          # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::0-255            1      0.01%  
    0.01% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::256-511            0      
0.00%      0.01% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::512-767            1      
0.01%      0.03% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::768-1023            1      
0.01%      0.04% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::1024-1279            0      
0.00%      0.04% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::1280-1535            0      
0.00%      0.04% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::1536-1791            2      
0.03%      0.07% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::1792-2047            1      
0.01%      0.09% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::2048-2303            0      
0.00%      0.09% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::2304-2559            0      
0.00%      0.09% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::2560-2815            0      
0.00%      0.09% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::2816-3071            1      
0.01%      0.10% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::3072-3327            1      
0.01%      0.12% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::3328-3583         6666     
99.85%     99.97% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::3584-3839            2      
0.03%    100.00% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::3840-4095            0      
0.00%    100.00% # Writes linear distribution
+system.monitor.stack_dist_calc.writeLinearHist::total         6676             
          # Writes linear distribution
+system.monitor.stack_dist_calc.writeLogHist::samples         6676              
         # Writes logarithmic distribution
+system.monitor.stack_dist_calc.writeLogHist::7            1                    
   # Writes logarithmic distribution
+system.monitor.stack_dist_calc.writeLogHist::9            2                    
   # Writes logarithmic distribution
+system.monitor.stack_dist_calc.writeLogHist::10            3                   
    # Writes logarithmic distribution
+system.monitor.stack_dist_calc.writeLogHist::11         6670                   
    # Writes logarithmic distribution
 system.monitor.readBurstLengthHist::samples            1                       
# Histogram of burst lengths of transmitted packets
 system.monitor.readBurstLengthHist::mean           64                       # 
Histogram of burst lengths of transmitted packets
 system.monitor.readBurstLengthHist::gmean    64.000000                       # 
Histogram of burst lengths of transmitted packets
@@ -60,7 +111,7 @@
 system.monitor.readBurstLengthHist::72-75            0      0.00%    100.00% # 
Histogram of burst lengths of transmitted packets
 system.monitor.readBurstLengthHist::76-79            0      0.00%    100.00% # 
Histogram of burst lengths of transmitted packets
 system.monitor.readBurstLengthHist::total            1                       # 
Histogram of burst lengths of transmitted packets
-system.monitor.writeBurstLengthHist::samples      3333268                      
 # Histogram of burst lengths of transmitted packets
+system.monitor.writeBurstLengthHist::samples        13333                      
 # Histogram of burst lengths of transmitted packets
 system.monitor.writeBurstLengthHist::mean           64                       # 
Histogram of burst lengths of transmitted packets
 system.monitor.writeBurstLengthHist::gmean    64.000000                       
# Histogram of burst lengths of transmitted packets
 system.monitor.writeBurstLengthHist::stdev            0                       
# Histogram of burst lengths of transmitted packets
@@ -80,11 +131,11 @@
 system.monitor.writeBurstLengthHist::52-55            0      0.00%      0.00% 
# Histogram of burst lengths of transmitted packets
 system.monitor.writeBurstLengthHist::56-59            0      0.00%      0.00% 
# Histogram of burst lengths of transmitted packets
 system.monitor.writeBurstLengthHist::60-63            0      0.00%      0.00% 
# Histogram of burst lengths of transmitted packets
-system.monitor.writeBurstLengthHist::64-67      3333268    100.00%    100.00% 
# Histogram of burst lengths of transmitted packets
+system.monitor.writeBurstLengthHist::64-67        13333    100.00%    100.00% 
# Histogram of burst lengths of transmitted packets
 system.monitor.writeBurstLengthHist::68-71            0      0.00%    100.00% 
# Histogram of burst lengths of transmitted packets
 system.monitor.writeBurstLengthHist::72-75            0      0.00%    100.00% 
# Histogram of burst lengths of transmitted packets
 system.monitor.writeBurstLengthHist::76-79            0      0.00%    100.00% 
# Histogram of burst lengths of transmitted packets
-system.monitor.writeBurstLengthHist::total      3333268                       
# Histogram of burst lengths of transmitted packets
+system.monitor.writeBurstLengthHist::total        13333                       
# Histogram of burst lengths of transmitted packets
 system.monitor.readBandwidthHist::samples          100                       # 
Histogram of read bandwidth per sample period (bytes/s)
 system.monitor.readBandwidthHist::mean            640                       # 
Histogram of read bandwidth per sample period (bytes/s)
 system.monitor.readBandwidthHist::gmean             0                       # 
Histogram of read bandwidth per sample period (bytes/s)
@@ -113,32 +164,32 @@
 system.monitor.averageReadBandwidth               640      0.00%      0.00% # 
Average read bandwidth (bytes/s)
 system.monitor.totalReadBytes                      64                       # 
Number of bytes read
 system.monitor.writeBandwidthHist::samples          100                       
# Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::mean    2133291520                       # 
Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::gmean 2133291510.261604                     
  # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::stdev       204800                       # 
Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::0-1.34218e+08            0      0.00%      
0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::1.34218e+08-2.68435e+08            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::2.68435e+08-4.02653e+08            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::4.02653e+08-5.36871e+08            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::5.36871e+08-6.71089e+08            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::6.71089e+08-8.05306e+08            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::8.05306e+08-9.39524e+08            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::9.39524e+08-1.07374e+09            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::1.07374e+09-1.20796e+09            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::1.20796e+09-1.34218e+09            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::1.34218e+09-1.4764e+09            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::1.4764e+09-1.61061e+09            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::1.61061e+09-1.74483e+09            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::1.74483e+09-1.87905e+09            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::1.87905e+09-2.01327e+09            0      
0.00%      0.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::2.01327e+09-2.14748e+09          100    
100.00%    100.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::2.14748e+09-2.2817e+09            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::2.2817e+09-2.41592e+09            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::2.41592e+09-2.55014e+09            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
-system.monitor.writeBandwidthHist::2.55014e+09-2.68435e+09            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::mean       8533120                       # 
Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::gmean            0                       # 
Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::stdev 42014178.909506                       
# Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::0-1.67772e+07           96     96.00%     
96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::1.67772e+07-3.35544e+07            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::3.35544e+07-5.03316e+07            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::5.03316e+07-6.71089e+07            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::6.71089e+07-8.38861e+07            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::8.38861e+07-1.00663e+08            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::1.00663e+08-1.17441e+08            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::1.17441e+08-1.34218e+08            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::1.34218e+08-1.50995e+08            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::1.50995e+08-1.67772e+08            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::1.67772e+08-1.84549e+08            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::1.84549e+08-2.01327e+08            0      
0.00%     96.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::2.01327e+08-2.18104e+08            4      
4.00%    100.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::2.18104e+08-2.34881e+08            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::2.34881e+08-2.51658e+08            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::2.51658e+08-2.68435e+08            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::2.68435e+08-2.85213e+08            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::2.85213e+08-3.0199e+08            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::3.0199e+08-3.18767e+08            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
+system.monitor.writeBandwidthHist::3.18767e+08-3.35544e+08            0      
0.00%    100.00% # Histogram of write bandwidth (bytes/s)
 system.monitor.writeBandwidthHist::total          100                       # 
Histogram of write bandwidth (bytes/s)
-system.monitor.averageWriteBandwidth       2133291520      0.00%      0.00% # 
Average write bandwidth (bytes/s)
-system.monitor.totalWrittenBytes            213329152                       # 
Number of bytes written
+system.monitor.averageWriteBandwidth          8533120      0.00%      0.00% # 
Average write bandwidth (bytes/s)
+system.monitor.totalWrittenBytes               853312                       # 
Number of bytes written
 system.monitor.readLatencyHist::samples             1                       # 
Read request-response latency
 system.monitor.readLatencyHist::mean            30000                       # 
Read request-response latency
 system.monitor.readLatencyHist::gmean    30000.000000                       # 
Read request-response latency
@@ -164,10 +215,10 @@
 system.monitor.readLatencyHist::36864-38911            0      0.00%    100.00% 
# Read request-response latency
 system.monitor.readLatencyHist::38912-40959            0      0.00%    100.00% 
# Read request-response latency
 system.monitor.readLatencyHist::total               1                       # 
Read request-response latency
-system.monitor.writeLatencyHist::samples      3333267                       # 
Write request-response latency
-system.monitor.writeLatencyHist::mean    30000.000098                       # 
Write request-response latency
-system.monitor.writeLatencyHist::gmean   30000.000081                       # 
Write request-response latency
-system.monitor.writeLatencyHist::stdev       0.179655                       # 
Write request-response latency
+system.monitor.writeLatencyHist::samples        13333                       # 
Write request-response latency
+system.monitor.writeLatencyHist::mean    30000.024601                       # 
Write request-response latency
+system.monitor.writeLatencyHist::gmean   30000.024467                       # 
Write request-response latency
+system.monitor.writeLatencyHist::stdev       2.840599                       # 
Write request-response latency
 system.monitor.writeLatencyHist::0-2047             0      0.00%      0.00% # 
Write request-response latency
 system.monitor.writeLatencyHist::2048-4095            0      0.00%      0.00% 
# Write request-response latency
 system.monitor.writeLatencyHist::4096-6143            0      0.00%      0.00% 
# Write request-response latency
@@ -182,13 +233,13 @@
 system.monitor.writeLatencyHist::22528-24575            0      0.00%      
0.00% # Write request-response latency
 system.monitor.writeLatencyHist::24576-26623            0      0.00%      
0.00% # Write request-response latency
 system.monitor.writeLatencyHist::26624-28671            0      0.00%      
0.00% # Write request-response latency
-system.monitor.writeLatencyHist::28672-30719      3333267    100.00%    
100.00% # Write request-response latency
+system.monitor.writeLatencyHist::28672-30719        13333    100.00%    
100.00% # Write request-response latency
 system.monitor.writeLatencyHist::30720-32767            0      0.00%    
100.00% # Write request-response latency
 system.monitor.writeLatencyHist::32768-34815            0      0.00%    
100.00% # Write request-response latency
 system.monitor.writeLatencyHist::34816-36863            0      0.00%    
100.00% # Write request-response latency
 system.monitor.writeLatencyHist::36864-38911            0      0.00%    
100.00% # Write request-response latency
 system.monitor.writeLatencyHist::38912-40959            0      0.00%    
100.00% # Write request-response latency
-system.monitor.writeLatencyHist::total        3333267                       # 
Write request-response latency
+system.monitor.writeLatencyHist::total          13333                       # 
Write request-response latency
 system.monitor.ittReadRead::samples                 0                       # 
Read-to-read inter transaction time
 system.monitor.ittReadRead::mean                  nan                       # 
Read-to-read inter transaction time
 system.monitor.ittReadRead::stdev                 nan                       # 
Read-to-read inter transaction time
@@ -217,62 +268,62 @@
 system.monitor.ittReadRead::min_value               0                       # 
Read-to-read inter transaction time
 system.monitor.ittReadRead::max_value               0                       # 
Read-to-read inter transaction time
 system.monitor.ittReadRead::total                   0                       # 
Read-to-read inter transaction time
-system.monitor.ittWriteWrite::samples         3333267                       # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::mean       30000.595310                       # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::stdev        547.340980                       # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::samples           13332                       # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::mean       255099.334533                       # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::stdev      14999776.110169                       
# Write-to-write inter transaction time
 system.monitor.ittWriteWrite::underflows            0      0.00%      0.00% # 
Write-to-write inter transaction time
 system.monitor.ittWriteWrite::1-5000                0      0.00%      0.00% # 
Write-to-write inter transaction time
 system.monitor.ittWriteWrite::5001-10000            0      0.00%      0.00% # 
Write-to-write inter transaction time
 system.monitor.ittWriteWrite::10001-15000            0      0.00%      0.00% # 
Write-to-write inter transaction time
 system.monitor.ittWriteWrite::15001-20000            0      0.00%      0.00% # 
Write-to-write inter transaction time
 system.monitor.ittWriteWrite::20001-25000            0      0.00%      0.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::25001-30000      3333167    100.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::30001-35000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::35001-40000           99      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::40001-45000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::45001-50000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::50001-55000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::55001-60000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::60001-65000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::65001-70000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::70001-75000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::75001-80000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::80001-85000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::85001-90000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::90001-95000            0      0.00%    100.00% # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::95001-100000            0      0.00%    100.00% 
# Write-to-write inter transaction time
-system.monitor.ittWriteWrite::overflows             1      0.00%    100.00% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::25001-30000        13328     99.97%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::30001-35000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::35001-40000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::40001-45000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::45001-50000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::50001-55000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::55001-60000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::60001-65000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::65001-70000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::70001-75000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::75001-80000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::80001-85000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::85001-90000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::90001-95000            0      0.00%     99.97% # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::95001-100000            0      0.00%     99.97% 
# Write-to-write inter transaction time
+system.monitor.ittWriteWrite::overflows             4      0.03%    100.00% # 
Write-to-write inter transaction time
 system.monitor.ittWriteWrite::min_value         30000                       # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::max_value       1024328                       # 
Write-to-write inter transaction time
-system.monitor.ittWriteWrite::total           3333267                       # 
Write-to-write inter transaction time
-system.monitor.ittReqReq::samples             3333268                       # 
Request-to-request inter transaction time
-system.monitor.ittReqReq::mean           30000.587712                       # 
Request-to-request inter transaction time
-system.monitor.ittReqReq::stdev            547.516688                       # 
Request-to-request inter transaction time
+system.monitor.ittWriteWrite::max_value    1000040000                       # 
Write-to-write inter transaction time
+system.monitor.ittWriteWrite::total             13332                       # 
Write-to-write inter transaction time
+system.monitor.ittReqReq::samples               13333                       # 
Request-to-request inter transaction time
+system.monitor.ittReqReq::mean           255080.552014                       # 
Request-to-request inter transaction time
_______________________________________________
gem5-dev mailing list
gem5-dev@gem5.org
http://m5sim.org/mailman/listinfo/gem5-dev

Reply via email to